@@ -17,6 +17,7 @@
 #' @param type shall only the file be retrieved (default) 
 #' \code{type = "download"} or should the corresponding file be downloaded and 
 #' subsequently be imported \code{type = "import"}.
+#' @param reference a logical value indicating whether or not a genome shall be downloaded if it isn't marked in the database as either a reference genome or a representative genome.
 #' @param path a character string specifying the location (a folder) in
 #' which the corresponding file shall be stored. Default is 
 #' \code{path} = \code{file.path("_ncbi_downloads","genomeassembly_stats")}.
@@ -67,6 +68,7 @@
 getAssemblyStats <-
     function(db = "refseq",
              organism,
+             reference = TRUE,
              type = "download",
              path = file.path("_ncbi_downloads", "genomeassembly_stats")) {
         
@@ -86,6 +88,9 @@ getAssemblyStats <-
                 call. = FALSE
             )
         
+        message("Starting assembly quality stats retrieval of '", organism, "' from ", db, " ...")
+        message("\n")
+        
         # get Kingdom Assembly Summary file
         AssemblyFilesAllKingdoms <-
             getKingdomAssemblySummary(db = db)
@@ -104,26 +109,34 @@ getAssemblyStats <-
         organism <- stringr::str_replace_all(organism, "\\(", "")
         organism <- stringr::str_replace_all(organism, "\\)", "")
         
-        FoundOrganism <-
-            dplyr::filter(
-                AssemblyFilesAllKingdoms,
-                stringr::str_detect(organism_name, organism),
-                ((refseq_category == "representative genome") |
-                     (refseq_category == "reference genome")
-                ),
-                (version_status == "latest")
-            )
+        if (reference) {
+                FoundOrganism <-
+                        dplyr::filter(
+                                AssemblyFilesAllKingdoms,
+                                stringr::str_detect(organism_name, organism),
+                                ((refseq_category == "representative genome") |
+                                         (refseq_category == "reference genome")
+                                ),
+                                (version_status == "latest")
+                        ) 
+        } else {
+                FoundOrganism <-
+                        dplyr::filter(
+                                AssemblyFilesAllKingdoms,
+                                stringr::str_detect(organism_name, organism),
+                                (version_status == "latest")
+                        ) 
+        }
         
         if (nrow(FoundOrganism) == 0) {
-            message(
-                paste0(
-                "----------> No genome assembly stats file for a reference ",
-                    "genome or representative genome was found for '",
-                    organism,
-                    "'. Thus, download for this species has been omitted."
+                message(
+                        paste0(
+                                "----------> No reference genome or representative genome was found for '",
+                                organism, "'. Thus, download for this species has been omitted.",
+                                " Have you tried to specify 'reference = FALSE' ?"
+                        )
                 )
-            )
-            return("Not available")
+                return("Not available")
         } else {
             if (nrow(FoundOrganism) > 1) {
                 warnings(
@@ -189,6 +202,9 @@ getAssemblyStats <-
                                 mode = "wb"
                             )
                         )
+                           
+                        message("Genome assembly quality stats file download completed!")
+                        
                         # download md5checksum file for organism of interest
                         custom_download(
                             paste0(FoundOrganism$ftp_path,"/md5checksums.txt"),
