@@ -2,13 +2,13 @@
 #' @description This funcion queries the BioMart Interface and returns a table
 #' storing all available attributes for a specific dataset.
 #' 
-#' @param mart a character string specifying the database (mart) for which datasets shall be listed.
-#' @param dataset a character string specifying the dataset for which attributes shall be listed.
+#' @param mart a character string specifying the database (mart) 
+#' for which datasets shall be listed.
+#' @param dataset a character string specifying the dataset for which 
+#' attributes shall be listed.
 #' @author Hajk-Georg Drost
 #' @examples
-#' 
 #' \dontrun{
-#' 
 #' # search for available datasets
 #' getMarts()
 #' 
@@ -17,40 +17,49 @@
 #' head(getDatasets(mart = "ENSEMBL_MART_ENSEMBL"), 10)
 #' 
 #' # choose dataset: "hsapiens_gene_ensembl"
-#' head(getAttributes(mart = "ENSEMBL_MART_ENSEMBL", dataset = "hsapiens_gene_ensembl") , 5)
-#' 
+#' head(getAttributes(mart = "ENSEMBL_MART_ENSEMBL", 
+#'                    dataset = "hsapiens_gene_ensembl") , 5)
 #' }
-#' 
-#' @seealso \code{\link{getMarts}}, \code{\link{getDatasets}}, \code{\link{getFilters}}, \code{\link{organismBM}}, \code{\link{organismFilters}}, \code{\link{organismAttributes}}
+#' @seealso \code{\link{getMarts}}, \code{\link{getDatasets}},
+#' \code{\link{getFilters}}, \code{\link{organismBM}}, 
+#' \code{\link{organismFilters}}, \code{\link{organismAttributes}}
 #' @export
+
 getAttributes <- function(mart, dataset){
-        
-        if ((!is.character(mart)) || (!is.character(dataset)))
-                stop("Please use a character string as mart or dataset.", call. = FALSE)
     
+    if ((!is.character(mart)) || (!is.character(dataset)))
+        stop("Please use a character string as mart or dataset.",
+             call. = FALSE)
+   
+    if (!is.element(mart, getMarts()$mart))
+        stop("Please select a valid mart with getMarts().", call. = FALSE)
+    
+    if (!is.element(dataset, getDatasets(mart = mart)$dataset))
+        stop("Please select a valid dataset with getDatasets().", call. = FALSE)
+     
     if (stringr::str_detect(mart, "ENSEMBL"))
         # connect to BioMart API
         url <-
             paste0(
-                "http://ensembl.org/biomart/martservice?type=attributes&dataset=",
+              "http://ensembl.org/biomart/martservice?type=attributes&dataset=",
                 dataset,
                 "&requestid=biomart&mart=",
                 mart
-            )    
+            )
     if (stringr::str_detect(mart, "plants"))
         # connect to BioMart API
         url <-
             paste0(
-                "http://plants.ensembl.org/biomart/martservice?type=attributes&dataset=",
+       "http://plants.ensembl.org/biomart/martservice?type=attributes&dataset=",
                 dataset,
                 "&requestid=biomart&mart=",
                 mart
-            )    
+            )
     if (stringr::str_detect(mart, "fung"))
         # connect to BioMart API
         url <-
             paste0(
-                "http://fungi.ensembl.org/biomart/martservice?type=attributes&dataset=",
+        "http://fungi.ensembl.org/biomart/martservice?type=attributes&dataset=",
                 dataset,
                 "&requestid=biomart&mart=",
                 mart
@@ -60,26 +69,30 @@ getAttributes <- function(mart, dataset){
         # connect to BioMart API
         url <-
             paste0(
-                "http://protist.ensembl.org/biomart/martservice?type=attributes&dataset=",
+      "http://protist.ensembl.org/biomart/martservice?type=attributes&dataset=",
                 dataset,
                 "&requestid=biomart&mart=",
                 mart
-            )    
+            )
     if (stringr::str_detect(mart, "metazoa"))
         # connect to BioMart API
         url <-
             paste0(
-                "http://metazoa.ensembl.org/biomart/martservice?type=attributes&dataset=",
+      "http://metazoa.ensembl.org/biomart/martservice?type=attributes&dataset=",
                 dataset,
                 "&requestid=biomart&mart=",
                 mart
-            )    
-        
-    
-    
-    testContent <- httr::content(httr::GET(url), as = "text", encoding = "UTF-8")
+            )
+
+    testContent <-
+        httr::content(httr::GET(url), as = "text", encoding = "UTF-8")
     if (testContent == "Attribute 'mains' does not exist\n") {
-        warning("No attributes were available for mart = ",mart," and dataset = ",dataset,".", call. = FALSE)
+        warning("No attributes were available for mart = ",
+                mart,
+                " and dataset = ",
+                dataset,
+                ".",
+                call. = FALSE)
         attrBioMart <- data.frame(name = "NA", description = "NA")
         return(attrBioMart)
     }
@@ -92,11 +105,13 @@ getAttributes <- function(mart, dataset){
     # extract attribute name and attribute description
     suppressWarnings(rawDF <-
                          do.call("rbind", apply(as.data.frame(strsplit(
-                             httr::content(xmlContentAttributes, as = "text", encoding = "UTF-8"), "\n"
+                             httr::content(xmlContentAttributes, as = "text", 
+                                           encoding = "UTF-8"),
+                             "\n"
                          )), 1, function(x)
                              unlist(strsplit(x, "\t")))))
     
-    colnames(rawDF) <- paste0("V", 1:ncol(rawDF))
+    colnames(rawDF) <- paste0("V", seq_len(ncol(rawDF)))
     
     attrBioMart <-
         as.data.frame(rawDF[, c("V1", "V2")],
