@@ -14,6 +14,7 @@
 #' } 
 #' @param organism a character string specifying the scientific name of the 
 #' organism of interest, e.g. \code{organism = "Homo sapiens"}.
+#' @param reference a logical value indicating whether or not a genome shall be downloaded if it isn't marked in the database as either a reference genome or a representative genome.
 #' @param path a character string specifying the location (a folder) in which 
 #' the corresponding annotation file shall be stored. Default is 
 #' \code{path = file.path("_ncbi_downloads","genomes")}.
@@ -53,6 +54,7 @@
 getGFF <-
     function(db = "refseq",
              organism,
+             reference = TRUE,
              path = file.path("_ncbi_downloads", "annotation")) {
        if (!is.element(db, c("refseq", "genbank", "ensembl", "ensemblgenomes")))
             stop(
@@ -60,8 +62,9 @@ getGFF <-
                 'genbank', 'ensembl', 'ensemblgenomes'."
             )
         
-        message("Starting retrieval of ", organism," ...")
-            
+        message("Starting gff retrieval of '", organism, "' from ", db, " ...")
+        message("\n")
+        
         if (is.element(db, c("refseq", "genbank"))) {
             # get Kingdom Assembly Summary file
             AssemblyFilesAllKingdoms <-
@@ -83,26 +86,34 @@ getGFF <-
                 stringr::str_replace_all(organism, "\\)", "")
             
             
-            FoundOrganism <-
-                dplyr::filter(
-                    AssemblyFilesAllKingdoms,
-                    stringr::str_detect(organism_name, organism),
-                    ((refseq_category == "representative genome") |
-                         (refseq_category == "reference genome")
-                    ),
-                    (version_status == "latest")
-                )
+            if (reference) {
+                    FoundOrganism <-
+                            dplyr::filter(
+                                    AssemblyFilesAllKingdoms,
+                                    stringr::str_detect(organism_name, organism),
+                                    ((refseq_category == "representative genome") |
+                                             (refseq_category == "reference genome")
+                                    ),
+                                    (version_status == "latest")
+                            ) 
+            } else {
+                    FoundOrganism <-
+                            dplyr::filter(
+                                    AssemblyFilesAllKingdoms,
+                                    stringr::str_detect(organism_name, organism),
+                                    (version_status == "latest")
+                            ) 
+            }
             
             if (nrow(FoundOrganism) == 0) {
-                message(
-                    paste0(
-                        "----------> No reference genome or representative 
-                        genome was found for '",
-                        organism,
-                        "'. Thus, download for this species has been omitted."
+                    message(
+                            paste0(
+                                    "----------> No reference genome or representative genome was found for '",
+                                    organism, "'. Thus, download for this species has been omitted.",
+                                    " Have you tried to specify 'reference = FALSE' ?"
+                            )
                     )
-                )
-                return("Not available")
+                    return("Not available")
             } else {
                 if (nrow(FoundOrganism) > 1) {
                     warnings(
@@ -170,6 +181,8 @@ getGFF <-
                                 )
                             )
                             
+                           message("GFF download is completed!")
+                                
                             # download md5checksum file for organism of interest
                             custom_download(
                             paste0(FoundOrganism$ftp_path,"/md5checksums.txt"),
