@@ -9,6 +9,7 @@
 #' \code{db = "ensembl"} or \code{db = "ensemblgenomes"}.
 #' @param organism a character string specifying the scientific name of the 
 #' organism of interest,\code{organism = "Homo sapiens"}.
+#' @param reference a logical value indicating whether or not a genome shall be downloaded if it isn't marked in the database as either a reference genome or a representative genome.
 #' @param path a character string specifying the location (a folder) in which 
 #' the corresponding
 #' CDS file shall be stored. Default is 
@@ -33,6 +34,7 @@
 getRNA <-
     function(db = "refseq",
              organism,
+             reference = TRUE,
              path = file.path("_ncbi_downloads", "RNA")) {
         if (!is.element(db, c("refseq", "genbank", "ensembl", 
                               "ensemblgenomes")))
@@ -42,8 +44,9 @@ getRNA <-
                 call. = FALSE
             )
             
-        message("Starting retrieval of ", organism, " ...")
-            
+        message("Starting RNA retrieval of '", organism, "' from ", db, " ...")
+        message("\n")
+        
         if (is.element(db, c("refseq", "genbank"))) {
             # get Kingdom Assembly Summary file
             AssemblyFilesAllKingdoms <-
@@ -63,25 +66,32 @@ getRNA <-
             organism <-
                 stringr::str_replace_all(organism, "\\)", "")
             
-            FoundOrganism <- dplyr::filter(
-                AssemblyFilesAllKingdoms,
-                stringr::str_detect(organism_name, organism),
-                ((refseq_category == "representative genome") |
-                     (refseq_category == "reference genome")
-                ),
-                (version_status == "latest")
-            )
+            if (reference) {
+                    FoundOrganism <-
+                            dplyr::filter(
+                                    AssemblyFilesAllKingdoms,
+                                    stringr::str_detect(organism_name, organism),
+                                    ((refseq_category == "representative genome") |
+                                             (refseq_category == "reference genome")
+                                    ),
+                                    (version_status == "latest")
+                            ) 
+            } else {
+                    FoundOrganism <-
+                            dplyr::filter(
+                                    AssemblyFilesAllKingdoms,
+                                    stringr::str_detect(organism_name, organism),
+                                    (version_status == "latest")
+                            ) 
+            }
             
             if (nrow(FoundOrganism) == 0) {
-                message(
-                    paste0(
-                        "----------> No reference genome or representative 
-                        genome was found for '",
-                        organism,
-                        "'. Thus, download for this species has been omitted."
+                    message("----------> No reference genome or representative genome was found for '",
+                      organism, "'. Thus, download for this species has been omitted.",
+                      " Have you tried to specify 'reference = FALSE' or have you tried to re-run the function yet?"
+                            
                     )
-                )
-                return("Not available")
+                    return("Not available")
             } else {
                 if (nrow(FoundOrganism) > 1) {
                     warnings(
@@ -165,6 +175,8 @@ getRNA <-
                                 )
                             )
                             
+                            message("RNA download is completed!")
+                                
                             # download md5checksum file for organism of interest
                             custom_download(
                              paste0(FoundOrganism$ftp_path,"/md5checksums.txt"),
